@@ -18,13 +18,12 @@ class Device(enum.Enum):
 
 
 class HyperParam(tb.Struct):
-    """
-    Benefits of this way of organizing the hyperparameters:
+    """Use this class to organize model hyperparameters:
     * one place to control everything: a control panel.
     * When doing multiple experiments, one command in console reminds you of settings used in that run (hp.__dict__).
     * Ease of saving settings of experiments! and also replicating it later.
     """
-    subpath = tb.P('metadata/hyper_params')
+    subpath = tb.P('metadata/hyper_params')  # location within model directory where this will be saved.
 
     def __init__(self, *args, **kwargs):
         super().__init__(
@@ -39,7 +38,7 @@ class HyperParam(tb.Struct):
             precision='float32',
             # ===================== Model =============================
             # ===================== Training ==========================
-            split=0.2,
+            split=0.2,  # test split
             lr=0.0005,
             batch_size=32,
             epochs=30,
@@ -52,18 +51,18 @@ class HyperParam(tb.Struct):
 
     @property
     def save_dir(self):
-        return (self.root / self.exp_name).create()
+        return self.root / self.exp_name
 
-    def save(self, **kwargs):
+    def save(self):
         self.save_dir.joinpath(self.subpath / '.txt').write_text(data=str(self))
-        super(HyperParam, self).save(path=self.save_dir.joinpath(self.subpath))
+        super(HyperParam, self).save(path=self.save_dir.joinpath(self.subpath / ".pkl"))
 
     @classmethod
-    def from_saved(cls, path, **kwargs):
+    def from_saved(cls, path):
         return (tb.P(path) / HyperParam.subpath / ".pkl").readit()
 
     def __repr__(self):
-        self.print()
+        self.print(config=True)
 
     @property
     def pkg(self):
@@ -180,8 +179,8 @@ class DataReader(object):
         self.split = split
         self.plotter = None
 
-    def __str__(self):
-        return f"DataReader Object with these keys: \n{self.__dict__.keys()}"
+    def __repr__(self):
+        return f"DataReader Object with these keys: \n" + self.specs.keys().__str__()
 
     def data_split(self, *args, strings=None, **kwargs):
         """
@@ -426,7 +425,7 @@ class BaseModel(ABC):
         results = tb.Struct(pp_prediction=pred, prediction=prediction, input=x_test, pp_gt=gt, gt=y_test,
                             names=names_test, loss_df=loss_dict, )
         if viz:
-            loss_name = results.loss_df.columns.to_list()[0]  # first loss name
+            loss_name = results.loss_df.columns.to_list()[0]  # first loss path
             loss_label = results.loss_df[loss_name].apply(lambda x: f"{loss_name} = {x}").to_list()
             names = [f"{aname}. Case: {anindex}" for aname, anindex in zip(loss_label, names_test)]
             self.viz(pred, gt, names=names, **kwargs)
@@ -439,17 +438,17 @@ class BaseModel(ABC):
         metrics = tb.L([self.compiler.loss]) + self.compiler.metrics
         loss_dict = dict()
         for a_metric in metrics:
-            if hasattr(a_metric, "name"):
+            if hasattr(a_metric, "path"):
                 name = a_metric.name
             elif hasattr(a_metric, "__name__"):
                 name = a_metric.__name__
             else:
                 name = "unknown"
             # try:  # EAFP principle.
-            #     name = a_metric.name  # works for subclasses Metrics
+            #     path = a_metric.path  # works for subclasses Metrics
             # except AttributeError:
             #
-            #     name = a_metric.__name__  # works for functions.
+            #     path = a_metric.__name__  # works for functions.
             loss_dict[name] = []
 
             for a_prediction, a_y_test in zip(prediction, groun_truth):
@@ -460,19 +459,19 @@ class BaseModel(ABC):
         return tb.pd.DataFrame(loss_dict)
 
     def save_model(self, directory):
-        self.model.save(directory)  # In TF: send only folder name. Save name is saved_model.pb
+        self.model.save(directory)  # In TF: send only path path. Save path is saved_model.pb
 
     def save_weights(self, directory):
-        self.model.save_weights(directory.joinpath(self.model.name))  # TF: last part of path is file name.
+        self.model.save_weights(directory.joinpath(self.model.name))  # TF: last part of path is file path.
 
     @staticmethod
     def load_model(directory):
         import tensorflow as tf
-        return tf.keras.models.load_model(directory)  # path to folder. file saved_model.pb is read auto.
+        return tf.keras.models.load_model(directory)  # path to path. file saved_model.pb is read auto.
 
     def load_weights(self, directory):
         name = directory.glob('*.data*').__next__().__str__().split('.data')[0]
-        self.model.load_weights(name)  # requires path to file name.
+        self.model.load_weights(name)  # requires path to file path.
 
     def save_class(self, weights_only=True, version='0', **kwargs):
         """Simply saves everything:
@@ -486,14 +485,14 @@ class BaseModel(ABC):
         :return:
 
         """
-        self.hp.save()  # goes into the meta folder.
-        self.data.save()  # goes into the meta folder.
-        tb.Save.pickle(obj=self.history, path=self.hp.save_dir / 'metadata/history.pkl')  # goes into the meta folder.
-        # model save goes into data folder.
+        self.hp.save()  # goes into the meta path.
+        self.data.save()  # goes into the meta path.
+        tb.Save.pickle(obj=self.history, path=self.hp.save_dir / 'metadata/history.pkl')  # goes into the meta path.
+        # model save goes into data path.
         save_dir = self.hp.save_dir.joinpath(f'{"weights" if weights_only else "model"}_save_v{version}').create()
         if weights_only: self.save_weights(save_dir)
         else: self.save_model(save_dir)
-        # Saving wrapper_class and model architecture in the main folder:
+        # Saving wrapper_class and model architecture in the main path:
         tb.Experimental.generate_readme(self.hp.save_dir, obj=self.__class__, **kwargs)
         print(f'Model class saved successfully!, check out: {self.hp.save_dir.as_uri()}')
 
@@ -728,7 +727,7 @@ class KerasOptimizer:
         pass
 
     def tune(self):
-        kt = tb.E.assert_package_installed("kerastuner")
+        kt = tb.core.assert_package_installed("kerastuner")
         self.tuner = kt.Hyperband(self,
                                   objective='loss',
                                   max_epochs=10,
