@@ -82,7 +82,7 @@ def encrypt(msg: bytes, key=None, pwd: str = None, salted=True, iteration: int =
     if pwd is not None and salted is True:
         from base64 import urlsafe_b64encode as b64e
         from base64 import urlsafe_b64decode as b64d
-        return b64e(b'%b%b%b' % (salt, iterations.to_bytes(4, 'big'), b64d(code)))
+        return b64e(b'%b%b%b' % (salt, iteration.to_bytes(4, 'big'), b64d(code)))
     else:
         return code
 
@@ -250,7 +250,7 @@ class P(type(Path()), Path):
     def time(self, which="m", **kwargs):
         """Meaning of ``which values``
             * ``m`` time of modifying file ``content``, i.e. the time it was created.
-            * ``c`` time of changing file status (its inode is changed like permissions, name etc, but not content)
+            * ``c`` time of changing file status (its inode is changed like permissions, path etc, but not content)
             * ``a`` last time the file was accessed.
 
         :param which: Determines which time to be returned. Three options are availalable:
@@ -319,28 +319,28 @@ class P(type(Path()), Path):
     # ================================ Path Object management ===========================================
     @property
     def trunk(self):
-        """ useful if you have multiple dots in file name where .stem fails.
+        """ useful if you have multiple dots in file path where `.stem` fails.
         """
         return self.name.split('.')[0]
 
-    def prepend(self, prefix, suffix=None):
-        """Add extra text before file name
+    def prepend(self, prefix, suffix=None, inplace=False):
+        """Add extra text before file path
         e.g: blah\blah.extenion ==> becomes ==> blah/name_blah.extension.
         notice that `__add__` method removes the extension, while this one preserves it.
         """
         if suffix is None: suffix = ''.join(self.suffixes)
-        return self.parent.joinpath(prefix + self.trunk + suffix)
+        return self._return(self.parent.joinpath(prefix + self.trunk + suffix), inplace)
 
-    def append(self, name='', suffix=None):
-        """Add extra text after file name, and optionally add extra suffix.
+    def append(self, name='', suffix=None, inplace=False):
+        """Add extra text after file path, and optionally add extra suffix.
         e.g: blah\blah.extenion ==> becomes ==> blah/blah_name.extension
         """
         if suffix is None: suffix = ''.join(self.suffixes)
-        return self.parent.joinpath(self.trunk + name + suffix)
+        return self._return(self.parent.joinpath(self.trunk + name + suffix), inplace)
 
-    def with_trunk(self, name):
+    def with_trunk(self, name, inplace=False):
         """Complementary to `with_stem` and `with_suffic`"""
-        return self.parent.joinpath(name + "".join(self.suffixes))
+        return self._return(self.parent.joinpath(name + "".join(self.suffixes)), inplace)
 
     @property
     def items(self):
@@ -367,25 +367,23 @@ class P(type(Path()), Path):
     #         tmp = tmp[1:]
     #     return P(other) / tmp
 
-    def append_time_stamp(self, fmt=None):
-        return self.append(name="_" + timestamp(fmt=fmt))
+    def append_time_stamp(self, fmt=None, inplace=False):
+        return self._return(self.append(name="_" + timestamp(fmt=fmt)), inplace)
 
-    def rel2home(self):
-        return P(self.relative_to(Path.home()))
+    def rel2home(self, inplace=False):
+        return self._return(P(self.relative_to(Path.home())), inplace)
 
-    def collapseuser(self):
+    def collapseuser(self, strict=True, inplace=False):
         """same as rel2home except that it adds the tilde `~` to indicated home at the beginning.
          Thus, it is a self-contained absolute path, bar a `expanduser` method."""
         if "~" in self: return self
-        assert str(P.home()) in str(self), ValueError(f"{str(P.home())} is not in the subpath of {str(self)}"
-                                                      f" OR one path is relative and the other is absolute.")
-        return "~" / (self - P.home())
+        if strict:
+            assert str(P.home()) in str(self), ValueError(f"{str(P.home())} is not in the subpath of {str(self)}"
+                                                          f" OR one path is relative and the other is absolute.")
+        return self._return("~" / (self - P.home()), inplace)
 
-    def rel2cwd(self):
-        return P(self.relative_to(Path.cwd()))
-
-    # def abs_from_home(self):
-    #     return P.home() / self
+    def rel2cwd(self, inplace=False):
+        return self._return(P(self.relative_to(Path.cwd())), inplace)
 
     def split(self, at: str = None, index: int = None, sep: int = 1, mode=["strict", "lenient"][0]):
         """Splits a path at a given string or index
@@ -480,15 +478,22 @@ class P(type(Path()), Path):
     def len(self):
         return self.__len__()
 
-    def switch(self, key: str, val: str):
-        """Changes a given part of the path to another given one. `replace` is an already defined method."""
-        return P(str(self).replace(key, val))
+    def _return(self, res, inplace: bool):
+        if not inplace:
+            return res
+        else:
+            self._str = str(res)
+            return self
 
-    def switch_by_index(self, key: int, val: str):
+    def switch(self, key: str, val: str, inplace=False):
+        """Changes a given part of the path to another given one. `replace` is an already defined method."""
+        return self._return(str(self).replace(key, val), inplace)
+
+    def switch_by_index(self, key: int, val: str, inplace=False):
         """Changes a given index of the path to another given one"""
         fullparts = list(self.parts)
         fullparts[key] = val
-        return P(*fullparts)
+        return self._return(P(*fullparts), inplace)
 
     def __deepcopy__(self, memodict=None):
         if memodict is None:
@@ -514,7 +519,7 @@ class P(type(Path()), Path):
             rep += " Relative " + "'" + str(self) + "'"
         return rep
 
-    def clickable(self):
+    def clickable(self, inplace=False):
         """
         Design point:
         `absolute` converts relative to absolute paths.
@@ -522,7 +527,7 @@ class P(type(Path()), Path):
         `expanduser` handles the ~ in path.
         :return:
         """
-        return self.expanduser().absolute().as_uri()  # .resolve()
+        return self._return(self.expanduser().absolute().as_uri(), inplace)  # .resolve()
 
     def _spec(self):
         if self.absolute():
@@ -535,14 +540,14 @@ class P(type(Path()), Path):
         else:  # there is no tell whether it is a file or directory.
             return "Relative"
 
-    def as_url_str(self):
+    def as_url_str(self, inplace=False):
         string_ = self.as_posix()
         string_ = string_.replace("https:/", "https://").replace("http:/", "http://")
-        return string_
+        return self._return(string_, inplace)
 
-    def as_url_obj(self):
+    def as_url_obj(self, inplace=False):
         urllib3 = assert_package_installed("urllib3")
-        return urllib3.connection_from_url(self)
+        return self._return(urllib3.connection_from_url(self), inplace)
 
     def __getstate__(self):
         return str(self)
@@ -560,7 +565,7 @@ class P(type(Path()), Path):
         return int("".join(filter(str.isdigit, str(astring))))
 
     def make_valid_filename(self, replace='_'):
-        """Converts arbitrary filename into proper variable name as per Python."""
+        """Converts arbitrary filename into proper variable path as per Python."""
         return self.make_valid_filename_(self.trunk, replace=replace)
 
     @staticmethod
@@ -569,19 +574,19 @@ class P(type(Path()), Path):
         return re.sub(r'^(?=\d)|\W', replace, str(astring))
 
     # =========================== OVERTIDE ===============================================
-    def as_unix(self):
+    def as_unix(self, inplace=False):
         """Similar to `as_posix()` but returns P object"""
-        return P(str(self).replace('\\', '/').replace('//', '/'))
+        return self._return(P(str(self).replace('\\', '/').replace('//', '/')), inplace)
 
-    def symlink_to(self, target, verbose=True, delete=False):
+    def symlink_to(self, target, verbose=True, inplace=False, orig=False):
         self.parent.create()
-        if delete:
+        if inplace:
             if self.is_symlink() or self.exists():
-            # self.exist() is False for broken links even though they exist
+                # self.exist() is False for broken links even though they exist
                 self.delete(sure=True, verbose=verbose)
         super(P, self).symlink_to(str(target))
         if verbose: print(f"LINKED {repr(self)}")
-        return P(target)
+        return P(target) if not orig else self
 
     @staticmethod
     def pwd():
@@ -600,9 +605,9 @@ class P(type(Path()), Path):
         :param newline: completely remove the line in which `txt` was found and replace it with `alt`.
         :return:
 
-        Works seamlessly for config files that has one-liners in it, which is invariably the case.
-        File is created if it doesn't exist.
-        Text is simply appended if not found in the text file.
+        * This method is suitable for config files and simple scripts that has one-liners in it,
+        * File is created if it doesn't exist.
+        * Text is simply appended if not found in the text file.
         """
         self.parent.create()
         if not self.exists(): self.write_text(txt)
@@ -621,110 +626,34 @@ class P(type(Path()), Path):
 
     # ==================================== File management =========================================
     def delete(self, sure=False, verbose=True):
+        slf = self.expanduser()
         if sure:
-            if not self.exists():
-                self.unlink(missing_ok=True)  # broken symlinks exhibit funny existence behaviour, catch them here.
-                if verbose: print(f"Could NOT DELETE nonexisting file {repr(self)}. ")
+            if not slf.exists():
+                slf.unlink(missing_ok=True)  # broken symlinks exhibit funny existence behaviour, catch them here.
+                if verbose: print(f"Could NOT DELETE nonexisting file {repr(slf)}. ")
                 return None  # terminate the function.
-            if self.is_file():
-                self.unlink(missing_ok=True)
+            if slf.is_file():
+                slf.unlink(missing_ok=True)
             else:
                 import shutil
-                shutil.rmtree(self, ignore_errors=True)
+                shutil.rmtree(slf, ignore_errors=True)
                 # self.rmdir()  # dir must be empty
-            if verbose: print(f"DELETED {repr(self)}.")
+            if verbose: print(f"DELETED {repr(slf)}.")
         else:
-            if verbose: print(f"Did NOT DELETE because user is not sure. file: {repr(self)}.")
+            if verbose: print(f"Did NOT DELETE because user is not sure. file: {repr(slf)}.")
+        return self
 
     def send2trash(self, verbose=True):
         send2trash = assert_package_installed("send2trash")
         if self.exists():
-            send2trash.send2trash(self.str)
+            send2trash.send2trash(self.expanduser().absolute().str)
             if verbose: print(f"TRASHED {repr(self)}")
         else:
             if verbose: print(f"Could NOT trash {self}")
-
-    def move(self, new_path, overwrite=False, verbose=True):
-        slf = self.absolute()
-
-        if overwrite:
-            str_ = randstr()
-            new_path = P(new_path).absolute() / str_  # no conflict with existing files/dirs of same `self.name`
-            slf.rename(new_path)  # no error are likely to occur as the random name won't cause conflict.
-            # now we can delete any potential conflict before eventually taking its name
-            (new_path.parent / slf.name).delete(sure=True, verbose=False)  # It is important to delete after moving
-            # because `self` could be within the file you want to delete.
-            new_path.rename(new_path.parent / slf.name)
-        else:
-            new_path = P(new_path).absolute() / slf.name
-            slf.rename(new_path)
-        if verbose: print(f"MOVED {repr(self)} ==> {repr(new_path)}`")
-        return new_path
-
-    def move_up(self, delete=True, content=False, overwrite=False):
-        if content:
-            self.search("*").apply(lambda x: x.move_up(delete=delete, content=False))
-            result = self.parent.parent
-        else:
-            result = self.move(self.parent.parent, overwrite=overwrite)
-        if result != self:
-            self.parent.delete(sure=delete)
-        return result
-
-    def renameit(self, new_file_name, verbose=True):
-        assert type(new_file_name) is str, "New new should be a string representing file name alone."
-        new_path = self.parent / new_file_name
-        self.rename(new_path)
-        if verbose: print(f"RENAMED {repr(self)} ==> {repr(new_path)}")
-        return new_path
-
-    def copy(self, target_dir=None, target_name=None, content=False, verbose=True, append=f"_copy_{randstr()}"):
-        """
-        :param append:
-        :param target_dir: copy the file to this directory (filename remains the same).
-        :param target_name: full path of destination (including -potentially different-  file name).
-        :param content: copy the parent directory or its content (relevant only if copying a directory)
-        :param verbose:
-        :return: path to copied file or directory.
-
-        .. wanring:: Do not confuse this with ``copy`` module that creates clones of Python objects.
-
-        """
-        dest = None  # destination.
-
-        if target_dir is not None:
-            assert target_name is None, f"You can either pass target_dir or target_name but not both"
-            dest = P(target_dir).create()  # / self.name
-
-        if target_name is not None:
-            assert target_dir is None, f"You can either pass target_dir or target_name but not both"
-            target_name = P(target_name)
-            target_name.parent.create()
-            dest = target_name
-
-        if dest is None:
-            dest = self.append(append)
-
-        if self.is_file():
-            import shutil
-            shutil.copy(str(self), str(dest))  # str() only there for Python < (3.6)
-            if verbose: print(f"COPIED {repr(self)} ==> {repr(dest)}")
-
-        elif self.is_dir():
-            from distutils.dir_util import copy_tree
-            if content:
-                copy_tree(str(self), str(dest))
-            else:
-                copy_tree(str(self), str(P(dest).joinpath(self.name).create()))
-            if verbose:
-                preface = "Content of " if content else ""
-                print(f"COPIED {preface} {repr(self)} ==> {repr(dest)}")
-        else:
-            print(f"Could NOT COPY. Not a file nor a folder: {repr(self)}.")
-        return dest / self.name
+        return self
 
     def clean(self, trash=True):
-        """removes content on a folder, rather than deleting the folder."""
+        """removes content on a path, rather than deleting the path."""
         content = self.listdir()
         for content in content:
             self.joinpath(content).send2trash() if trash else self.joinpath(content).delete(sure=True)
@@ -742,7 +671,7 @@ class P(type(Path()), Path):
         """
         filename = self
         if '.zip' in str(self):
-            filename = self.unzip(op_path=self.tmp(folder="unzipped"), verbose=verbose)
+            filename = self.unzip(folder=self.tmp(folder="unzipped"), verbose=verbose)
         try:
             if reader is None:  # infer the reader
                 return Read.read(filename, **kwargs)
@@ -765,7 +694,7 @@ class P(type(Path()), Path):
             return self
 
         # os.startfile(os.path.realpath(self))
-        filename = self.absolute().str
+        filename = self.expanduser().absolute().str
         if sys.platform == "win32":
             os.startfile(filename)  # works for files and folders alike
         elif sys.platform == 'linux':
@@ -776,15 +705,125 @@ class P(type(Path()), Path):
             # os.system(f"open {filename}")
             import subprocess
             subprocess.call(["open", filename])  # works for files and folders alike
+        return self
+
+    def move(self, folder=None, name=None, path=None, overwrite=False, verbose=True):
+        """
+        :param folder: directory
+        :param name: fname of the file
+        :param path: full path, that includes directory and file fname.
+        :param overwrite:
+        :param verbose:
+        :return:
+        """
+        if path is not None:
+            path = P(path).expanduser().absolute()
+            assert not path.is_dir(), f"`path` passed is a directory! it must not be that. If this is meant, pass it with `path` kwarg. {path}"
+            folder = path.parent
+            name = path.name
+            _ = name
+        else:
+            assert folder is not None, "`path` or `path` must be passed."
+            if name is None: name = self.absolute().name
+            else: name = str(name)  # good for edge cases of path with single part.
+            path = P(folder).expanduser().absolute() / name
+
+        slf = self.expanduser().absolute()
+
+        if overwrite:  # the following works safely even if you are moving a path up and parent has same path.
+            path_ = P(folder).absolute() / randstr()  # no conflict with existing files/dirs of same `self.path`
+            slf.rename(path_)  # no error are likely to occur as the random path won't cause conflict.
+            # now we can delete any potential conflict before eventually taking its path
+            path.delete(sure=True, verbose=False)  # It is important to delete after moving
+            # because `self` could be within the file you want to delete.
+            path_.rename(path)
+        else:
+            slf.rename(path)
+        if verbose: print(f"MOVED {repr(self)} ==> {repr(path)}`")
+        return path
+
+    def move_up(self, inplace=True, content=False, overwrite=False):
+        if content:
+            self.search("*").apply(lambda x: x.move_up(inplace=inplace, content=False))
+            result = self.parent.parent
+        else:
+            result = self.move(self.parent.parent, overwrite=overwrite)
+        if result != self:
+            self.parent.delete(sure=inplace)
+        return result
+
+    def renameit(self, name, verbose=True, orig=False):
+        """Unlike the builtin `rename`, this doesn't require or change full path, only file path."""
+        assert type(name) is str, "New new should be a string representing file path alone."
+        new_path = self.parent / name
+        self.rename(new_path)
+        if verbose: print(f"RENAMED {repr(self)} ==> {repr(new_path)}")
+        return new_path if not orig else self
+
+    def copy(self, folder=None, name=None, path=None, content=False, verbose=True, append=f"_copy_{randstr()}",
+             overwrite=False, orig=False):
+        """
+        :param orig:
+        :param overwrite:
+        :param name:
+        :param append:
+        :param folder: copy the file to this directory (filename remains the same).
+        :param path: full path of destination (including -potentially different-  file name).
+        :param content: copy the parent directory or its content (relevant only if copying a directory)
+        :param verbose:
+        :return: path to copied file or directory.
+
+        .. wanring:: Do not confuse this with ``copy`` module that creates clones of Python objects.
+
+        """
+        # tested %100
+        if folder is not None and path is None:
+            if name is None:
+                dest = P(folder).create()
+            else:
+                dest = P(folder) / name
+                content = True
+        elif path is not None and folder is None:
+            dest = P(path)
+            content = True  # this way, the destination will be filled with contents of `self`
+        elif path is None and folder is None:
+            dest = self.append(append)
+        else: raise NotImplementedError
+
+        dest = dest.expanduser().absolute().resolve()
+        slf = self.expanduser().absolute().resolve()
+
+        dest.parent.create()
+        if overwrite:
+            if dest.exists(): dest.delete(sure=True)
+        # TODO: shutil and copy_tree exhisbit different behaviour towards overwriting. make this method consistent.
+        # else:
+        #     assert not dest.exists()
+
+        if slf.is_file():
+            import shutil
+            shutil.copy(str(slf), str(dest))  # str() only there for Python < (3.6)
+            if verbose: print(f"COPIED {repr(slf)} ==> {repr(dest)}")
+
+        elif slf.is_dir():
+            from distutils.dir_util import copy_tree
+            if content:
+                copy_tree(str(slf), str(dest))
+            else:
+                copy_tree(str(slf), str(P(dest).joinpath(slf.name).create()))
+            if verbose:
+                preface = "Content of " if content else ""
+                print(f"COPIED {preface} {repr(slf)} ==> {repr(dest)}")
+        else:
+            print(f"Could NOT COPY. Not a file nor a path: {repr(slf)}.")
+        return dest / slf.name if not orig else self
 
     # ======================================== Folder management =======================================
     def create(self, parents=True, exist_ok=True, parent_only=False):
         """Creates directory while returning the same object
         """
-        if parent_only:
-            self.parent.mkdir(parents=parents, exist_ok=exist_ok)
-        else:
-            self.mkdir(parents=parents, exist_ok=exist_ok)
+        if parent_only: self.parent.mkdir(parents=parents, exist_ok=exist_ok)
+        else: self.mkdir(parents=parents, exist_ok=exist_ok)
         return self
 
     @property
@@ -823,22 +862,23 @@ class P(type(Path()), Path):
 
         # ============================ get generator of search results ========================================
 
-        if compressed and self.suffix == ".zip":
+        slf = self.expanduser().absolute()
+        if compressed and slf.suffix == ".zip":
             import zipfile
-            with zipfile.ZipFile(str(self)) as z:
+            with zipfile.ZipFile(str(slf)) as z:
                 content = List(z.namelist())
             from fnmatch import fnmatch
-            raw = content.filter(lambda x: fnmatch(x, pattern)).apply(lambda x: self / x)
+            raw = content.filter(lambda x: fnmatch(x, pattern)).apply(lambda x: slf / x)
 
         elif dotfiles:
-            raw = self.glob(pattern) if not r else self.rglob(pattern)
+            raw = slf.glob(pattern) if not r else self.rglob(pattern)
         else:  # glob ignroes dot and hidden files
             from glob import glob
             if r:
-                path = self / "**" / pattern
+                path = slf / "**" / pattern
                 raw = glob(str(path), recursive=r)
             else:
-                path = self.joinpath(pattern)
+                path = slf.joinpath(pattern)
                 raw = glob(str(path))
 
         if compressed:
@@ -849,12 +889,12 @@ class P(type(Path()), Path):
                                            dotfiles=dotfiles,
                                            absolute=absolute, filters=filters, not_in=not_in, win_order=win_order)
 
-            # if os.name == 'nt':
+            # if os.path == 'nt':
 
         #     import win32api, win32con
 
         # def folder_is_hidden(p):
-        #     if os.name == 'nt':
+        #     if os.path == 'nt':
         #         attribute = win32api.GetFileAttributes(p)
         #         return attribute & (win32con.FILE_ATTRIBUTE_HIDDEN | win32con.FILE_ATTRIBUTE_SYSTEM)
 
@@ -905,7 +945,7 @@ class P(type(Path()), Path):
             return List(processed)
 
     def listdir(self):
-        return List(os.listdir(self)).apply(P)
+        return List(os.listdir(self.expanduser().absolute())).apply(P)
 
     def find(self, *args, r=True, compressed=True, **kwargs):
         """short for the method ``search`` then pick first item from results.
@@ -961,61 +1001,76 @@ class P(type(Path()), Path):
 
     @staticmethod
     def tmpfile(name=None, suffix="", folder=None, tstamp=False):
-        return P.tmp(file=(name or randstr()) + "_" + randstr()  + (("_" + timestamp()) if tstamp else "") + suffix,
+        return P.tmp(file=(name or randstr()) + "_" + randstr() + (("_" + timestamp()) if tstamp else "") + suffix,
                      folder="tmpfiles" if folder is None else folder)
 
     # ====================================== Compression ===========================================
-    def zip(self, op_path=None, arcname=None, delete=False, verbose=True, content=True, **kwargs):
+    def zip(self, path=None, folder=None, name=None, arcname=None, inplace=False, verbose=True, content=True,
+            orig=False, **kwargs):
         """
         """
-        op_path = P(op_path or self)
-        arcname = P(arcname or self.name)
-        if arcname.name != self.name:
-            arcname /= self.name  # arcname has to start from somewhere and end with filename
-        if self.is_file():
-            if op_path.suffix != ".zip": op_path = op_path + f".zip"
-            op_path = Compression.zip_file(ip_path=self, op_path=op_path, arcname=arcname, **kwargs)
+        if folder is not None and path is None:
+            path = P(folder) / (name or self.name)
+        elif folder is None and path is not None:
+            path = P(path)
+        elif folder is None and path is None:
+            path = self
+        else: raise NotImplementedError("`path` and `folder` are passed. Only one is allowed.")
+
+        path = path.expanduser().absolute()
+        slf = self.expanduser().absolute()
+
+        arcname = P(arcname or slf.name)
+        if arcname.name != slf.name:
+            arcname /= slf.name  # arcname has to start from somewhere and end with filename
+        if slf.is_file():
+            if path.suffix != ".zip": path = path + f".zip"
+            path = Compression.zip_file(ip_path=slf, op_path=path, arcname=arcname, **kwargs)
         else:
             if content:
-                root_dir = self
+                root_dir = slf
                 base_dir = "."
             else:
-                root_dir = self.split(at=str(arcname[0]))[0]
+                root_dir = slf.split(at=str(arcname[0]))[0]
                 base_dir = arcname
-            op_path = Compression.compress_folder(root_dir=root_dir, op_path=op_path,
-                                                  base_dir=base_dir, fmt='zip', **kwargs)
-        if verbose: print(f"ZIPPED {repr(self)} ==>  {repr(op_path)}")
-        if delete: self.delete(sure=True, verbose=verbose)
-        return op_path
+            path = Compression.compress_folder(root_dir=root_dir, op_path=path,
+                                               base_dir=base_dir, fmt='zip', **kwargs)
+        if verbose: print(f"ZIPPED {repr(slf)} ==>  {repr(path)}")
+        if inplace: slf.delete(sure=True, verbose=verbose)
+        return path if not orig else self
 
-    def unzip(self, op_path=None, fname=None, verbose=True, content=False, delete=False, **kwargs):
+    def unzip(self, folder=None, fname=None, verbose=True, content=False, inplace=False, orig=False, **kwargs):
         """
-        :param op_path: directory where extracted files will live.
-        :param fname: a specific file name to be extracted from the archive.
+        :param orig:
+        :param folder: directory where extracted files will live.
+        :param fname: a specific file path to be extracted from the archive.
         :param verbose:
-        :param content: if set to True, all contents of the zip archive will be scattered in op_path dir.
-        If set to False, a directory with same name as the zip file will be created and will contain the results.
+        :param content: if set to True, all contents of the zip archive will be scattered in path dir.
+        If set to False, a directory with same path as the zip file will be created and will contain the results.
         :param delete: delete the original zip file after successful extraction.
         :param kwargs:
-        :return: op_path if content=False, else, op_path.parent. Default op_path = self.parent / self.stem
+        :return: path if content=False, else, path.parent. Default path = self.parent / self.stem
         """
-        zipfile = self
-        if self.suffix != ".zip":  # may be there is .zip somewhere in the path.
-            if ".zip" not in str(self): return self
-            zipfile, fname = self.split(at=List(self.parts).filter(lambda x: ".zip" in x)[0], sep=-1)
-        if op_path is None: op_path = zipfile.parent / zipfile.stem
-        else:  op_path = P(op_path).joinpath(zipfile.stem)
-        if content: op_path = op_path.parent
-        result = Compression.unzip(zipfile, op_path, fname, **kwargs)
+        slf = self.expanduser().absolute()
+        zipfile = slf
+        if slf.suffix != ".zip":  # may be there is .zip somewhere in the path.
+            if ".zip" not in str(slf): return slf
+            zipfile, fname = slf.split(at=List(slf.parts).filter(lambda x: ".zip" in x)[0], sep=-1)
+        if folder is None: folder = (zipfile.parent / zipfile.stem)
+        else:
+            folder = P(folder).joinpath(zipfile.stem).expanduser().absolute()
+            print(folder)
+        if content: folder = folder.parent
+        result = Compression.unzip(zipfile, folder, fname, **kwargs)
         if verbose:
             msg = f"UNZIPPED {repr(zipfile)} ==> {repr(result)}"
             print(msg)
-        if delete: self.delete(sure=True, verbose=verbose)
-        return result
+        if inplace: slf.delete(sure=True, verbose=verbose)
+        return result if not orig else self
 
-    def tar(self, op_path=None):
-        if op_path is None: op_path = self + '.gz'
-        result = Compression.untar(self, op_path=op_path)
+    def tar(self, path=None):
+        if path is None: path = self + '.gz'
+        result = Compression.untar(self, op_path=path)
         return result
 
     def untar(self, op_path, verbose=True):
@@ -1033,53 +1088,54 @@ class P(type(Path()), Path):
     def tar_gz(self):
         pass
 
-    def untar_ungz(self, op_path=None, delete=False, verbose=True):
-        op_path = op_path or P(self.parent) / P(self.stem)
-        intrem = self.ungz(op_path=op_path, verbose=verbose)
-        result = intrem.untar(op_path=op_path, verbose=verbose)
+    def untar_ungz(self, folder=None, inplace=False, verbose=True):
+        folder = folder or P(self.parent) / P(self.stem)
+        intrem = self.ungz(op_path=folder, verbose=verbose)
+        result = intrem.untar(op_path=folder, verbose=verbose)
         intrem.delete(sure=True, verbose=verbose)
-        if delete: self.delete(sure=True, verbose=verbose)
+        if inplace: self.delete(sure=True, verbose=verbose)
         return result
 
-    def compress(self, op_path=None, base_dir=None, fmt="zip", delete=False, **kwargs):
+    def compress(self, op_path=None, base_dir=None, fmt="zip", inplace=False, **kwargs):
         fmts = ["zip", "tar", "gzip"]
         assert fmt in fmts, f"Unsupported format {fmt}. The supported formats are {fmts}"
-        _ = self, op_path, base_dir, kwargs, delete
+        _ = self, op_path, base_dir, kwargs, inplace
         pass
 
     def decompress(self):
         pass
 
-    def encrypt(self, key=None, pwd=None, op_path=None, verbose=True, append="_encrypted", delete=False):
+    def encrypt(self, key=None, pwd=None, op_path=None, verbose=True, append="_encrypted", inplace=False, orig=False):
         """
         see: https://stackoverflow.com/questions/42568262/how-to-encrypt-text-with-a-password-in-python
         https://stackoverflow.com/questions/2490334/simple-way-to-encode-a-string-according-to-a-password
         """
-        assert self.is_file(), f"Cannot encrypt a directory. You might want to try `zip_n_encrypt`. {self}"
-        code = encrypt(msg=self.read_bytes(), key=key, pwd=pwd)
-        op_path = self.append(name=append) if op_path is None else P(op_path)
+        slf = self.expanduser().absolute()
+        assert slf.is_file(), f"Cannot encrypt a directory. You might want to try `zip_n_encrypt`. {self}"
+        code = encrypt(msg=slf.read_bytes(), key=key, pwd=pwd)
+        op_path = slf.append(name=append) if op_path is None else P(op_path)
         op_path.write_bytes(code)  # Fernet(key).encrypt(self.read_bytes()))
-        if verbose: print(f"ENCRYPTED: {repr(self)} ==> {repr(op_path)}.")
-        if delete: self.delete(sure=True, verbose=verbose)
-        return op_path
+        if verbose: print(f"ENCRYPTED: {repr(slf)} ==> {repr(op_path)}.")
+        if inplace: slf.delete(sure=True, verbose=verbose)
+        return op_path if not orig else self
 
-    def decrypt(self, key=None, pwd=None, op_path=None, verbose=True, append="_encrypted", delete=False):
-        op_path = P(op_path) if op_path is not None else self.switch(append, "")
-        print(self, str(self), repr(self))
-        op_path.write_bytes(decrypt(self.read_bytes(), key=key, pwd=pwd))  # Fernet(key).decrypt(self.read_bytes()))
-        if verbose: print(f"DECRYPTED: {repr(self)} ==> {repr(op_path)}.")
-        if delete: self.delete(sure=True, verbose=verbose)
-        return op_path
+    def decrypt(self, key=None, pwd=None, op_path=None, verbose=True, append="_encrypted", inplace=False, orig=False):
+        slf = self.expanduser().absolute()
+        op_path = P(op_path) if op_path is not None else slf.switch(append, "")
+        op_path.write_bytes(decrypt(slf.read_bytes(), key=key, pwd=pwd))  # Fernet(key).decrypt(self.read_bytes()))
+        if verbose: print(f"DECRYPTED: {repr(slf)} ==> {repr(op_path)}.")
+        if inplace: slf.delete(sure=True, verbose=verbose)
+        return op_path if not orig else self
 
-    def zip_n_encrypt(self, key=None, pwd=None, delete=False, verbose=True):
-        zipped = self.zip(delete=delete, verbose=verbose)
-        zipped_secured = zipped.encrypt(key=key, pwd=pwd, verbose=verbose, delete=True)
-        return zipped_secured
+    def zip_n_encrypt(self, key=None, pwd=None, inplace=False, verbose=True, orig=False):
+        zipped = self.zip(inplace=inplace, verbose=verbose)
+        zipped_secured = zipped.encrypt(key=key, pwd=pwd, verbose=verbose, inplace=True)
+        return zipped_secured if not orig else self
 
-    def decrypt_n_unzip(self, key=None, pwd=None, delete=False, verbose=True):
-        deciphered = self.decrypt(key=key, pwd=pwd, verbose=verbose, delete=delete)
-        unzipped = deciphered.unzip(op_path=None, delete=True, content=False)
-        return unzipped
+    def decrypt_n_unzip(self, key=None, pwd=None, inplace=False, verbose=True, orig=False):
+        deciphered = self.decrypt(key=key, pwd=pwd, verbose=verbose, inplace=inplace)
+        unzipped = deciphered.unzip(folder=None, inplace=True, content=False)
+        return unzipped if not orig else self
 
 
 class Compression(object):
@@ -1101,13 +1157,13 @@ class Compression(object):
         import shutil
         result_path = shutil.make_archive(base_name=op_path, format=fmt,
                                           root_dir=str(root_dir), base_dir=str(base_dir), **kwargs)
-        return P(result_path)  # same as op_path but (possibly) with format extension
+        return P(result_path)  # same as path but (possibly) with format extension
 
     @staticmethod
     def zip_file(ip_path, op_path, arcname=None, password=None, **kwargs):
         """
         arcname determines the directory of the file being archived inside the archive. Defaults to same
-        as original directory except for drive. When changed, it should still include the file name in its end.
+        as original directory except for drive. When changed, it should still include the file path in its end.
         If arcname = filename without any path, then, it will be in the root of the archive.
         """
         import zipfile
