@@ -134,7 +134,7 @@ class Experimental:
         print(f"Successfully generated README.md file. Checkout:\n", readmepath.absolute().as_uri())
 
         if save_source_code:
-            P(inspect.getmodule(obj).__file__).zip(op_path=readmepath.with_name("source_code.zip"))
+            P(inspect.getmodule(obj).__file__).zip(path=readmepath.with_name("source_code.zip"))
             print("Source code saved @ " + readmepath.with_name("source_code.zip").absolute().as_uri())
 
     @staticmethod
@@ -162,7 +162,7 @@ class Experimental:
         :param func:
         :param scope: `globals()` executed in the main scope. This provides the function with scope defined in main.
         :param args: dict of what you would like to pass to the function as arguments.
-        :param self: relevant only if the function is a method of a class. self refers to the name of the instance
+        :param self: relevant only if the function is a method of a class. self refers to the path of the instance
         :param update_scope: binary flag refers to whether you want the result in a struct or update main."""
         code = Experimental.extract_code(func, args=args, self=self, include_args=False, verbose=False,
                                          )
@@ -180,7 +180,7 @@ class Experimental:
     @staticmethod
     def extract_code(func, code: str = None, include_args=True, modules=None,
                      verbose=True, copy2clipboard=False, **kwargs):
-        """Takes in a function name, reads it source code and returns a new version of it that can be run in the main.
+        """Takes in a function path, reads it source code and returns a new version of it that can be run in the main.
         This is useful to debug functions and class methods alike.
         Use: in the main: exec(extract_code(func)) or is used by `run_globally` but you need to pass globals()
         TODO: how to handle decorated functions.
@@ -463,7 +463,6 @@ def batcherv2(func_type='function', order=1):
             def __call__(self, *args, **kwargs):
                 output = [self.func(self, *items, *args[order:], **kwargs) for items in zip(*args[:order])]
                 return np.array(output)
-
         return Batch
 
 
@@ -481,7 +480,7 @@ class Terminal:
 
         def __init__(self, stdin=None, stdout=None, stderr=None, cmd=None):
             self.std = dict(stdin=stdin, stdout=stdout, stderr=stderr)  # streams go here.
-            self.output = dict(stdin=None, stdout=None, stderr=None, returncode=None)
+            self.output = dict(stdin="", stdout="", stderr="", returncode=None)
             self.input = cmd  # input command
 
         def __call__(self, *args, **kwargs):
@@ -525,7 +524,7 @@ class Terminal:
         Shell
         Host
         * adding `start` to the begining of the command results in launching a new console that will not
-        inherit from the console python was launched from (e.g. conda enviroment), unlike when console name is ignored.
+        inherit from the console python was launched from (e.g. conda enviroment), unlike when console path is ignored.
 
         * `subprocess.Popen` (process open) is the most general command. Used here to create asynchronous job.
         * `subprocess.run` is a thin wrapper around Popen that makes it wait until it finishes the task.
@@ -680,9 +679,9 @@ tb.sys.path.insert(0, r'{wdir}')
         fname = P.tmpfile(tstamp=False, suffix=".pkl")
         Save.pickle(obj=obj, path=fname, verbose=False)
         script = f"""
-fname = tb.P(r'{fname}')
-obj = fname.readit()
-fname.delete(sure=True, verbose=False)
+path = tb.P(r'{fname}')
+obj = path.readit()
+path.delete(sure=True, verbose=False)
 """
         Terminal.run_script(script)
 
@@ -747,7 +746,7 @@ class SSH(object):
         print(f"Send `{source}` ==> `{remotepath}` ")
         self.sftp.put(localpath=P(source).expanduser(), remotepath=remotepath)
         if zip_n_encrypt:
-            resp = self.runpy(f"""tb.P(r"{remotepath}").expanduser().decrypt_n_unzip(pwd="{pwd}", delete=True)""")
+            resp = self.runpy(f"""tb.P(r"{remotepath}").expanduser().decrypt_n_unzip(pwd="{pwd}", inplace=True)""")
             return resp
 
     def copy_to_here(self, source, target=None):
@@ -793,13 +792,14 @@ class Log(object):
         self.dialect = dialect  # specific to this class
         self.verbose = verbose  # specific to coloredlogs dialect
         self.log_colors = log_colors  # specific kwarg to colorlog dialect
+        self.owners = []  # list of objects using this object to log. It won't be pickled anyway, no circularity prob
         if file is False and stream is False:
             self.logger = Null()
         else:
             self.logger = Null()  # to be populated by `_install`
             self._install()
             # update specs after intallation.
-            self.specs["name"] = self.logger.name
+            self.specs["path"] = self.logger.name
             if file:  # first handler is a file handler
                 self.specs["file_path"] = self.logger.handlers[0].baseFilename
 
@@ -821,6 +821,27 @@ class Log(object):
     def critical(self, msg):
         return self.logger.critical(msg)
 
+    def set_level(self, level, which=["logger", "stream", "file", "all"][0]):
+        if which in {"logger", "all"}: self.logger.setLevel(level)
+        if which in {"stream", "all"}: self.get_shandler().setLevel(level)
+        if which in {"file", "all"}: self.get_fhandler().setLevel(level)
+
+    def get_shandler(self, first=True):
+        shandlers = []
+        for handler in self.logger.handlers:
+            if "StreamHandler" in str(handler):
+                if first: return handler
+                else: shandlers.append(handler)
+        return shandlers
+
+    def get_fhandler(self, first=True):
+        fhandlers = []
+        for handler in self.logger.handlers:
+            if "FileHandler" in str(handler):
+                if first: return handler
+                else: fhandlers.append(handler)
+        return fhandlers
+
     @property
     def file(self):
         return P(self.specs["file_path"]) if self.specs["file_path"] else None
@@ -842,7 +863,8 @@ class Log(object):
         self._install()
 
     def __getstate__(self):
-        # logger can be pickled, but its handlers are lost, so what's the point? no perfect reconstruction.
+        # logger can be pickled without this method,
+        # but its handlers are lost, so what's the point? no perfect reconstruction.
         state = self.__dict__.copy()
         state["specs"] = state["specs"].copy()
         del state["logger"]
@@ -884,7 +906,7 @@ class Log(object):
         field_styles = {'asctime': {'color': 'green'},
                         'hostname': {'color': 'magenta'},
                         'levelname': {'color': 'black', 'bold': True},
-                        'name': {'color': 'blue'},
+                        'path': {'color': 'blue'},
                         'programname': {'color': 'cyan'},
                         'username': {'color': 'yellow'}}
         coloredlogs = assert_package_installed("coloredlogs")
@@ -934,7 +956,7 @@ class Log(object):
     @staticmethod
     def get_base_logger(module, name, l_level):
         if name is None:
-            print(f"Logger name not passed. It is preferable to pass a name indicates the owner.")
+            print(f"Logger path not passed. It is preferable to pass a path indicates the owner.")
         else:
             print(f"Logger `{name}` from `{module.__name__}` is instantiated with level {l_level}.")
         logger = module.getLogger(name=name or randstr())
@@ -949,15 +971,16 @@ class Log(object):
             Log.add_streamhandler(logger, s_level, fmt, module=module)
 
     @staticmethod
-    def add_streamhandler(logger, s_level=logging.DEBUG, fmt=None, module=logging):
+    def add_streamhandler(logger, s_level=logging.DEBUG, fmt=None, module=logging, name="myStream"):
         shandler = module.StreamHandler()
         shandler.setLevel(level=s_level)
         shandler.setFormatter(fmt=fmt)
+        shandler.set_name(name)
         logger.addHandler(shandler)
         print(f"    Level {s_level} stream handler for Logger `{logger.name}` is created.")
 
     @staticmethod
-    def add_filehandler(logger, file_path=None, fmt=None, f_level=logging.DEBUG, mode="a", name="fileHandler"):
+    def add_filehandler(logger, file_path=None, fmt=None, f_level=logging.DEBUG, mode="a", name="myFileHandler"):
         if file_path is None:
             file_path = P.tmpfile(name="logger", suffix=".log", folder="loggers")
         fhandler = logging.FileHandler(filename=str(file_path), mode=mode)
@@ -965,8 +988,7 @@ class Log(object):
         fhandler.setLevel(level=f_level)
         fhandler.set_name(name)
         logger.addHandler(fhandler)
-        print(f"    Level {f_level} file handler for Logger `{logger.name}` is created @ " + P(
-            file_path).absolute().as_uri())
+        print(f"    Level {f_level} file handler for Logger `{logger.name}` is created @ " + P(file_path).clickable())
 
     @staticmethod
     def test_logger(logger):
@@ -1131,5 +1153,5 @@ def qr(txt):
 
 
 if __name__ == '__main__':
-    # Log.get_colorlog()
-    Terminal().run("$profile", shell="pwsh").print()
+    # Terminal().run("$profile", shell="pwsh").print()
+    pass
